/*
  Copyright (c) 2015, Matthias Schiffer <mschiffer@universe-factory.net>
  All rights reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:

    1. Redistributions of source code must retain the above copyright notice,
       this list of conditions and the following disclaimer.
    2. Redistributions in binary form must reproduce the above copyright notice,
       this list of conditions and the following disclaimer in the documentation
       and/or other materials provided with the distribution.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
  DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
  SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
  CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#include "BlockType.hpp"


namespace MinedMap {
namespace Resource {

const BlockType BLOCK_TYPES[256] = {
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 0 */
	{true,  false, {0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 1 */
	{true,  true,  {0x939393, 0x939393, 0x939393, 0x939393, 0x939393, 0x939393, 0x939393, 0x939393, 0x939393, 0x939393, 0x939393, 0x939393, 0x939393, 0x939393, 0x939393, 0x939393,}}, /* 2 */
	{true,  false, {0x866043, 0x866043, 0x5a3f1c, 0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 3 */
	{true,  false, {0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a,}}, /* 4 */
	{true,  false, {0x9c7f4e, 0x674d2e, 0xc3b37b, 0x9a6e4d, 0xa95b33, 0x3d2712, 0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 5 */
	{true,  false, {0x476625, 0x333a21, 0x769654, 0x305612, 0x727314, 0x38561c, 0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 6 */
	{true,  false, {0x535353, 0x535353, 0x535353, 0x535353, 0x535353, 0x535353, 0x535353, 0x535353, 0x535353, 0x535353, 0x535353, 0x535353, 0x535353, 0x535353, 0x535353, 0x535353,}}, /* 7 */
	{true,  false, {0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4, 0x3147f4,}}, /* 8 */
	{true,  false, {0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4, 0x2e43f4,}}, /* 9 */
	{true,  false, {0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13, 0xcf5b13,}}, /* 10 */
	{true,  false, {0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12, 0xd45a12,}}, /* 11 */
	{true,  false, {0xdbd3a0, 0xdbd3a0, 0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 12 */
	{true,  false, {0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a, 0x7e7c7a,}}, /* 13 */
	{true,  false, {0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c, 0x8f8b7c,}}, /* 14 */
	{true,  false, {0x87827e, 0x87827e, 0x87827e, 0x87827e, 0x87827e, 0x87827e, 0x87827e, 0x87827e, 0x87827e, 0x87827e, 0x87827e, 0x87827e, 0x87827e, 0x87827e, 0x87827e, 0x87827e,}}, /* 15 */
	{true,  false, {0x737373, 0x737373, 0x737373, 0x737373, 0x737373, 0x737373, 0x737373, 0x737373, 0x737373, 0x737373, 0x737373, 0x737373, 0x737373, 0x737373, 0x737373, 0x737373,}}, /* 16 */
	{true,  false, {0x9a7d4d, 0x685130, 0xb8a679, 0x997649, 0x665131, 0x2d1c0c, 0xcecec9, 0x57431a, 0x665131, 0x2d1c0c, 0xcecec9, 0x57431a, 0x665131, 0x2d1c0c, 0xcecec9, 0x57431a,}}, /* 17 */
	{true,  true,  {0x878787, 0x747474, 0x878787, 0x918e86, 0x878787, 0x747474, 0x878787, 0x918e86, 0x878787, 0x747474, 0x878787, 0x918e86, 0x878787, 0x747474, 0x878787, 0x918e86,}}, /* 18 */
	{true,  false, {0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354, 0xc2c354,}}, /* 19 */
	{true,  false, {0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4,}}, /* 20 */
	{true,  false, {0x667086, 0x667086, 0x667086, 0x667086, 0x667086, 0x667086, 0x667086, 0x667086, 0x667086, 0x667086, 0x667086, 0x667086, 0x667086, 0x667086, 0x667086, 0x667086,}}, /* 21 */
	{true,  false, {0x264389, 0x264389, 0x264389, 0x264389, 0x264389, 0x264389, 0x264389, 0x264389, 0x264389, 0x264389, 0x264389, 0x264389, 0x264389, 0x264389, 0x264389, 0x264389,}}, /* 22 */
	{true,  false, {0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060,}}, /* 23 */
	{true,  false, {0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e,}}, /* 24 */
	{true,  false, {0x644332, 0x644332, 0x644332, 0x644332, 0x644332, 0x644332, 0x644332, 0x644332, 0x644332, 0x644332, 0x644332, 0x644332, 0x644332, 0x644332, 0x644332, 0x644332,}}, /* 25 */
	{true,  false, {0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616, 0x8e1616,}}, /* 26 */
	{true,  false, {0x846c48, 0x846c48, 0x846c48, 0x846c48, 0x846c48, 0x846c48, 0x846c48, 0x846c48, 0x846c48, 0x846c48, 0x846c48, 0x846c48, 0x846c48, 0x846c48, 0x846c48, 0x846c48,}}, /* 27 */
	{true,  false, {0x786559, 0x786559, 0x786559, 0x786559, 0x786559, 0x786559, 0x786559, 0x786559, 0x786559, 0x786559, 0x786559, 0x786559, 0x786559, 0x786559, 0x786559, 0x786559,}}, /* 28 */
	{true,  false, {0x606060, 0x8d9263, 0x6a665f, 0x6a665f, 0x6a665f, 0x6a665f, 0x8d9263, 0,        0x606060, 0x8d9263, 0x6a665f, 0x6a665f, 0x6a665f, 0x6a665f, 0x8d9263, 0,       }}, /* 29 */
	{true,  false, {0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc, 0xdcdcdc,}}, /* 30 */
	{false, true,  {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 31 */
	{false, true,  {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 32 */
	{true,  false, {0x606060, 0x998159, 0x6a665f, 0x6a665f, 0x6a665f, 0x6a665f, 0x998159, 0,        0x606060, 0x998159, 0x6a665f, 0x6a665f, 0x6a665f, 0x6a665f, 0x998159, 0,       }}, /* 33 */
	{true,  false, {0x998159, 0x998159, 0x998159, 0x998159, 0x998159, 0x998159, 0,        0,        0x8d9263, 0x8d9263, 0x8d9263, 0x8d9263, 0x8d9263, 0x8d9263, 0,        0,       }}, /* 34 */
	{true,  false, {0xdddddd, 0xdb7d3e, 0xb350bc, 0x6a8ac9, 0xb1a627, 0x41ae38, 0xd08499, 0x404040, 0x9aa1a1, 0x2e6e89, 0x7e3db5, 0x2e388d, 0x4f321f, 0x35461b, 0x963430, 0x191616,}}, /* 35 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 36 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 37 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 38 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 39 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 40 */
	{true,  false, {0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e,}}, /* 41 */
	{true,  false, {0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb,}}, /* 42 */
	{true,  false, {0x9f9f9f, 0xdad29e, 0x9c7f4e, 0x7a7a7a, 0x926356, 0x7a7a7a, 0x2c161a, 0xece9e2, 0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 43 */
	{true,  false, {0x9f9f9f, 0xdad29e, 0x9c7f4e, 0x7a7a7a, 0x926356, 0x7a7a7a, 0x2c161a, 0xece9e2, 0x9f9f9f, 0xdad29e, 0x9c7f4e, 0x7a7a7a, 0x926356, 0x7a7a7a, 0x2c161a, 0xece9e2,}}, /* 44 */
	{true,  false, {0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356,}}, /* 45 */
	{true,  false, {0x82412f, 0x82412f, 0x82412f, 0x82412f, 0x82412f, 0x82412f, 0x82412f, 0x82412f, 0x82412f, 0x82412f, 0x82412f, 0x82412f, 0x82412f, 0x82412f, 0x82412f, 0x82412f,}}, /* 46 */
	{true,  false, {0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e,}}, /* 47 */
	{true,  false, {0x677967, 0x677967, 0x677967, 0x677967, 0x677967, 0x677967, 0x677967, 0x677967, 0x677967, 0x677967, 0x677967, 0x677967, 0x677967, 0x677967, 0x677967, 0x677967,}}, /* 48 */
	{true,  false, {0x14121d, 0x14121d, 0x14121d, 0x14121d, 0x14121d, 0x14121d, 0x14121d, 0x14121d, 0x14121d, 0x14121d, 0x14121d, 0x14121d, 0x14121d, 0x14121d, 0x14121d, 0x14121d,}}, /* 49 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 50 */
	{true,  false, {0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35, 0xd38c35,}}, /* 51 */
	{true,  false, {0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731, 0x1a2731,}}, /* 52 */
	{true,  false, {0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e,}}, /* 53 */
	{true,  false, {0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e,}}, /* 54 */
	{true,  false, {0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09,}}, /* 55 */
	{true,  false, {0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f, 0x818c8f,}}, /* 56 */
	{true,  false, {0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5, 0x61dbd5,}}, /* 57 */
	{true,  false, {0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a, 0x6b472a,}}, /* 58 */
	{true,  false, {0x00b312, 0x12ac0f, 0x1c890b, 0x258b08, 0x2e8007, 0x427b07, 0x507607, 0x566607, 0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 59 */
	{true,  false, {0x734b2d, 0x4b280d, 0x4b280d, 0x4b280d, 0x4b280d, 0x4b280d, 0x4b280d, 0x4b280d, 0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 60 */
	{true,  false, {0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060,}}, /* 61 */
	{true,  false, {0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060,}}, /* 62 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 63 */
	{true,  false, {0x866532, 0x866532, 0x866532, 0x866532, 0x866532, 0x866532, 0x866532, 0x866532, 0x866532, 0x866532, 0x866532, 0x866532, 0x866532, 0x866532, 0x866532, 0x866532,}}, /* 64 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 65 */
	{true,  false, {0x796c58, 0x796c58, 0x796c58, 0x796c58, 0x796c58, 0x796c58, 0x796c58, 0x796c58, 0x796c58, 0x796c58, 0x796c58, 0x796c58, 0x796c58, 0x796c58, 0x796c58, 0x796c58,}}, /* 66 */
	{true,  false, {0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a,}}, /* 67 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 68 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 69 */
	{true,  false, {0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d, 0x7d7d7d,}}, /* 70 */
	{true,  false, {0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3, 0xa3a3a3,}}, /* 71 */
	{true,  false, {0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e,}}, /* 72 */
	{true,  false, {0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b,}}, /* 73 */
	{true,  false, {0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b, 0x846b6b,}}, /* 74 */
	{true,  false, {0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09,}}, /* 75 */
	{true,  false, {0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09,}}, /* 76 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 77 */
	{true,  false, {0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb,}}, /* 78 */
	{true,  false, {0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff, 0x7dadff,}}, /* 79 */
	{true,  false, {0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb, 0xeffbfb,}}, /* 80 */
	{true,  false, {0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318, 0x0d6318,}}, /* 81 */
	{true,  false, {0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0, 0x9ea4b0,}}, /* 82 */
	{true,  false, {0x94c065, 0x94c065, 0x94c065, 0x94c065, 0x94c065, 0x94c065, 0x94c065, 0x94c065, 0x94c065, 0x94c065, 0x94c065, 0x94c065, 0x94c065, 0x94c065, 0x94c065, 0x94c065,}}, /* 83 */
	{true,  false, {0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937, 0x6b4937,}}, /* 84 */
	{true,  false, {0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e,}}, /* 85 */
	{true,  false, {0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615,}}, /* 86 */
	{true,  false, {0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634, 0x6f3634,}}, /* 87 */
	{true,  false, {0x544033, 0x544033, 0x544033, 0x544033, 0x544033, 0x544033, 0x544033, 0x544033, 0x544033, 0x544033, 0x544033, 0x544033, 0x544033, 0x544033, 0x544033, 0x544033,}}, /* 88 */
	{true,  false, {0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645, 0x8f7645,}}, /* 89 */
	{true,  false, {0x570abf, 0x570abf, 0x570abf, 0x570abf, 0x570abf, 0x570abf, 0x570abf, 0x570abf, 0x570abf, 0x570abf, 0x570abf, 0x570abf, 0x570abf, 0x570abf, 0x570abf, 0x570abf,}}, /* 90 */
	{true,  false, {0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615, 0xc07615,}}, /* 91 */
	{true,  false, {0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce, 0xe4cdce,}}, /* 92 */
	{true,  false, {0x979393, 0x979393, 0x979393, 0x979393, 0x979393, 0x979393, 0x979393, 0x979393, 0x979393, 0x979393, 0x979393, 0x979393, 0x979393, 0x979393, 0x979393, 0x979393,}}, /* 93 */
	{true,  false, {0xa09393, 0xa09393, 0xa09393, 0xa09393, 0xa09393, 0xa09393, 0xa09393, 0xa09393, 0xa09393, 0xa09393, 0xa09393, 0xa09393, 0xa09393, 0xa09393, 0xa09393, 0xa09393,}}, /* 94 */
	{true,  false, {0xffffff, 0xd87f33, 0xb24cd8, 0x6699d8, 0xe5e533, 0x7fcc19, 0xf27fa5, 0x4c4c4c, 0x999999, 0x4c7f99, 0x7f3fb2, 0x334cb2, 0x664c33, 0x667f33, 0x993333, 0x191919,}}, /* 95 */
	{true,  false, {0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d, 0x7e5d2d,}}, /* 96 */
	{true,  false, {0x7d7d7d, 0x7a7a7a, 0x7a7a7a, 0x72776a, 0x767676, 0x767676, 0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 97 */
	{true,  false, {0x7a7a7a, 0x72776a, 0x767676, 0x767676, 0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 98 */
	{true,  false, {0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53, 0x8d6a53,}}, /* 99 */
	{true,  false, {0xb62524, 0xb62524, 0xb62524, 0xb62524, 0xb62524, 0xb62524, 0xb62524, 0xb62524, 0xb62524, 0xb62524, 0xb62524, 0xb62524, 0xb62524, 0xb62524, 0xb62524, 0xb62524,}}, /* 100 */
	{true,  false, {0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a, 0x6d6c6a,}}, /* 101 */
	{true,  false, {0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4, 0xdaf0f4,}}, /* 102 */
	{true,  false, {0x979924, 0x979924, 0x979924, 0x979924, 0x979924, 0x979924, 0x979924, 0x979924, 0x979924, 0x979924, 0x979924, 0x979924, 0x979924, 0x979924, 0x979924, 0x979924,}}, /* 103 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 104 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 105 */
	{true,  true,  {0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f, 0x6f6f6f,}}, /* 106 */
	{true,  false, {0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e,}}, /* 107 */
	{true,  false, {0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356, 0x926356,}}, /* 108 */
	{true,  false, {0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a, 0x7a7a7a,}}, /* 109 */
	{true,  false, {0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369, 0x6f6369,}}, /* 110 */
	{true,  true,  {0x767676, 0x767676, 0x767676, 0x767676, 0x767676, 0x767676, 0x767676, 0x767676, 0x767676, 0x767676, 0x767676, 0x767676, 0x767676, 0x767676, 0x767676, 0x767676,}}, /* 111 */
	{true,  false, {0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a,}}, /* 112 */
	{true,  false, {0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a,}}, /* 113 */
	{true,  false, {0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a, 0x2c161a,}}, /* 114 */
	{true,  false, {0x6a0e1e, 0x6c0f16, 0x6c0f16, 0x6f1211, 0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 115 */
	{true,  false, {0x67403b, 0x67403b, 0x67403b, 0x67403b, 0x67403b, 0x67403b, 0x67403b, 0x67403b, 0x67403b, 0x67403b, 0x67403b, 0x67403b, 0x67403b, 0x67403b, 0x67403b, 0x67403b,}}, /* 116 */
	{true,  false, {0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a, 0x6a6a6a,}}, /* 117 */
	{true,  false, {0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737,}}, /* 118 */
	{true,  false, {0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f,}}, /* 119 */
	{true,  false, {0x597560, 0x597560, 0x597560, 0x597560, 0x597560, 0x597560, 0x597560, 0x597560, 0x597560, 0x597560, 0x597560, 0x597560, 0x597560, 0x597560, 0x597560, 0x597560,}}, /* 120 */
	{true,  false, {0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5, 0xdddfa5,}}, /* 121 */
	{true,  false, {0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f,}}, /* 122 */
	{true,  false, {0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a, 0x462b1a,}}, /* 123 */
	{true,  false, {0x775937, 0x775937, 0x775937, 0x775937, 0x775937, 0x775937, 0x775937, 0x775937, 0x775937, 0x775937, 0x775937, 0x775937, 0x775937, 0x775937, 0x775937, 0x775937,}}, /* 124 */
	{true,  false, {0x9c7f4e, 0x674d2e, 0xc3b37b, 0x9a6e4d, 0xa95b33, 0x3d2712, 0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 125 */
	{true,  false, {0x9c7f4e, 0x674d2e, 0xc3b37b, 0x9a6e4d, 0xa95b33, 0x3d2712, 0,        0,        0x9c7f4e, 0x674d2e, 0xc3b37b, 0x9a6e4d, 0xa95b33, 0x3d2712, 0,        0,       }}, /* 126 */
	{true,  false, {0x8a8c40, 0x8a8c40, 0x8a8c40, 0x8a8c40, 0x896b33, 0x896b33, 0x896b33, 0x896b33, 0x91501e, 0x91501e, 0x91501e, 0x91501e, 0,        0,        0,        0,       }}, /* 127 */
	{true,  false, {0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e, 0xdad29e,}}, /* 128 */
	{true,  false, {0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074, 0x6d8074,}}, /* 129 */
	{true,  false, {0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f, 0x0c090f,}}, /* 130 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 131 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 132 */
	{true,  false, {0x51d975, 0x51d975, 0x51d975, 0x51d975, 0x51d975, 0x51d975, 0x51d975, 0x51d975, 0x51d975, 0x51d975, 0x51d975, 0x51d975, 0x51d975, 0x51d975, 0x51d975, 0x51d975,}}, /* 133 */
	{true,  false, {0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e,}}, /* 134 */
	{true,  false, {0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b,}}, /* 135 */
	{true,  false, {0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d,}}, /* 136 */
	{true,  false, {0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f, 0xb2896f,}}, /* 137 */
	{true,  false, {0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7, 0x74ddd7,}}, /* 138 */
	{true,  false, {0x7a7a7a, 0x677967, 0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 139 */
	{true,  false, {0x764133, 0x764133, 0x764133, 0x764133, 0x764133, 0x764133, 0x764133, 0x764133, 0x764133, 0x764133, 0x764133, 0x764133, 0x764133, 0x764133, 0x764133, 0x764133,}}, /* 140 */
	{true,  false, {0x01ab10, 0x01ab10, 0x01bb0f, 0x01bb0f, 0x00be10, 0x00be10, 0x158002, 0x158002, 0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 141 */
	{true,  false, {0x01ab10, 0x01ab10, 0x01bb0f, 0x01bb0f, 0x00be10, 0x00be10, 0x22aa24, 0x22aa24, 0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 142 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 143 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 144 */
	{true,  false, {0x403c3c, 0x403c3c, 0x403c3c, 0x403c3c, 0x403c3c, 0x403c3c, 0x403c3c, 0x403c3c, 0x403c3c, 0x403c3c, 0x403c3c, 0x403c3c, 0,        0,        0,        0,       }}, /* 145 */
	{true,  false, {0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e, 0x9c7f4e,}}, /* 146 */
	{true,  false, {0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e, 0xf9ec4e,}}, /* 147 */
	{true,  false, {0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb, 0xdbdbdb,}}, /* 148 */
	{true,  false, {0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695, 0x9c9695,}}, /* 149 */
	{true,  false, {0xa59594, 0xa59594, 0xa59594, 0xa59594, 0xa59594, 0xa59594, 0xa59594, 0xa59594, 0xa59594, 0xa59594, 0xa59594, 0xa59594, 0xa59594, 0xa59594, 0xa59594, 0xa59594,}}, /* 150 */
	{true,  false, {0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e,}}, /* 151 */
	{true,  false, {0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09, 0xab1b09,}}, /* 152 */
	{true,  false, {0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f, 0x7d544f,}}, /* 153 */
	{true,  false, {0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737, 0x373737,}}, /* 154 */
	{true,  false, {0xece9e2, 0xe7e4db, 0xe8e5dd, 0xe7e3db, 0xe7e3db, 0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 155 */
	{true,  false, {0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2, 0xece9e2,}}, /* 156 */
	{true,  false, {0x685347, 0x685347, 0x685347, 0x685347, 0x685347, 0x685347, 0x685347, 0x685347, 0x685347, 0x685347, 0x685347, 0x685347, 0x685347, 0x685347, 0x685347, 0x685347,}}, /* 157 */
	{true,  false, {0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060, 0x606060,}}, /* 158 */
	{true,  false, {0xd1b2a1, 0xa15325, 0x95586c, 0x716c89, 0xba8523, 0x677534, 0xa14e4e, 0x392a23, 0x876a61, 0x565b5b, 0x764656, 0x4a3b5b, 0x4d3323, 0x4c532a, 0x8f3d2e, 0x251610,}}, /* 159 */
	{true,  false, {0xffffff, 0xd87f33, 0xb24cd8, 0x6699d8, 0xe5e533, 0x7fcc19, 0xf27fa5, 0x4c4c4c, 0x999999, 0x4c7f99, 0x7f3fb2, 0x334cb2, 0x664c33, 0x667f33, 0x993333, 0x191919,}}, /* 160 */
	{true,  true,  {0x878787, 0x878787, 0,        0,        0x878787, 0x878787, 0,        0,        0x878787, 0x878787, 0,        0,        0x878787, 0x878787, 0,        0,       }}, /* 161 */
	{true,  true,  {0x9a5b40, 0x4e3e29, 0,        0,        0x696359, 0x342817, 0,        0,        0x696359, 0x342817, 0,        0,        0x696359, 0x342817, 0,        0,       }}, /* 162 */
	{true,  true,  {0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33,}}, /* 163 */
	{true,  true,  {0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712,}}, /* 164 */
	{true,  false, {0x78c865, 0x78c865, 0x78c865, 0x78c865, 0x78c865, 0x78c865, 0x78c865, 0x78c865, 0x78c865, 0x78c865, 0x78c865, 0x78c865, 0x78c865, 0x78c865, 0x78c865, 0x78c865,}}, /* 165 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 166 */
	{true,  false, {0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7, 0xc7c7c7,}}, /* 167 */
	{true,  false, {0x63988d, 0x63a08f, 0x3b574b, 0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 168 */
	{true,  false, {0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be, 0xacc7be,}}, /* 169 */
	{true,  true,  {0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10, 0xa88b10,}}, /* 170 */
	{true,  false, {0xdddddd, 0xdb7d3e, 0xb350bc, 0x6a8ac9, 0xb1a627, 0x41ae38, 0xd08499, 0x404040, 0x9aa1a1, 0x2e6e89, 0x7e3db5, 0x2e388d, 0x4f321f, 0x35461b, 0x963430, 0x191616,}}, /* 171 */
	{true,  false, {0x965c42, 0x965c42, 0x965c42, 0x965c42, 0x965c42, 0x965c42, 0x965c42, 0x965c42, 0x965c42, 0x965c42, 0x965c42, 0x965c42, 0x965c42, 0x965c42, 0x965c42, 0x965c42,}}, /* 172 */
	{true,  false, {0x121212, 0x121212, 0x121212, 0x121212, 0x121212, 0x121212, 0x121212, 0x121212, 0x121212, 0x121212, 0x121212, 0x121212, 0x121212, 0x121212, 0x121212, 0x121212,}}, /* 173 */
	{true,  false, {0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5, 0xa5c2f5,}}, /* 174 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 175 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 176 */
	{false, false, {0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000, 0x000000,}}, /* 177 */
	{true,  false, {0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e, 0x82745e,}}, /* 178 */
	{true,  false, {0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d,}}, /* 179 */
	{true,  false, {0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d,}}, /* 180 */
	{true,  false, {0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d,}}, /* 181 */
	{true,  false, {0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d, 0xa6551d,}}, /* 182 */
	{true,  false, {0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e,}}, /* 183 */
	{true,  false, {0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b,}}, /* 184 */
	{true,  false, {0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d,}}, /* 185 */
	{true,  false, {0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712,}}, /* 186 */
	{true,  false, {0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33,}}, /* 187 */
	{true,  false, {0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e, 0x674d2e,}}, /* 188 */
	{true,  false, {0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b, 0xc3b37b,}}, /* 189 */
	{true,  false, {0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d, 0x9a6e4d,}}, /* 190 */
	{true,  false, {0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712, 0x3d2712,}}, /* 191 */
	{true,  false, {0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33, 0xa95b33,}}, /* 192 */
	{true,  false, {0x614b31, 0x614b31, 0x614b31, 0x614b31, 0x614b31, 0x614b31, 0x614b31, 0x614b31, 0x614b31, 0x614b31, 0x614b31, 0x614b31, 0x614b31, 0x614b31, 0x614b31, 0x614b31,}}, /* 193 */
	{true,  false, {0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d, 0xc6bd8d,}}, /* 194 */
	{true,  false, {0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d, 0x926b4d,}}, /* 195 */
	{true,  false, {0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836, 0x9b5836,}}, /* 196 */
	{true,  false, {0x412c17, 0x412c17, 0x412c17, 0x412c17, 0x412c17, 0x412c17, 0x412c17, 0x412c17, 0x412c17, 0x412c17, 0x412c17, 0x412c17, 0x412c17, 0x412c17, 0x412c17, 0x412c17,}}, /* 197 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 198 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 199 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 200 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 201 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 202 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 203 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 204 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 205 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 206 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 207 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 208 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 209 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 210 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 211 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 212 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 213 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 214 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 215 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 216 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 217 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 218 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 219 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 220 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 221 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 222 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 223 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 224 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 225 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 226 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 227 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 228 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 229 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 230 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 231 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 232 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 233 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 234 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 235 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 236 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 237 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 238 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 239 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 240 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 241 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 242 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 243 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 244 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 245 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 246 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 247 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 248 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 249 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 250 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 251 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 252 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 253 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 254 */
	{false, false, {0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,        0,       }}, /* 255 */
};

}
}
